@@ -16,13 +16,7 @@
 
 # You should have received a copy of the GNU General Public License
 # along with fastSemSim.  If not, see <http://www.gnu.org/licenses/>.
-'''
-The FastSemSim package includes a command line utility to load ontologies and annotation corpora, and to avaluate the available semantic similarity measures.
 
-After installation, you may run the command line utility just by typing fastsemsim in your console.
-
-Please use fastsemsim -h to visualize the full set of parameters.
-'''
 
 __author__ = "Marco Mina"
 
@@ -599,9 +593,9 @@ def check_parameters():
 
 		if isinstance(params['query']['query_mode'], None.__class__):
 			if params['query']['query_input'] == 'ac':
-				params['query_mode'] = 'list'
+				params['query']['query_mode'] = 'list'
 			if params['query']['query_input'] == 'ontology':
-				params['query_mode'] = 'list'
+				params['query']['query_mode'] = 'list'
 			if params['query']['query_input'] == 'file':
 				raise Exception("The query_mode parameter must be specified if a query file is provided.")
 
@@ -898,7 +892,7 @@ def init_ss():
 		do_log = True
 
 	if params['query']['query_ss_type'] == 'term':
-		tss_class = SemSimMeasures.select_term_SemSim(params['ss']['tss_measure'])
+		tss_class = fastsemsim.SemSim.select_term_SemSim(params['ss']['tss_measure'])
 		tss = tss_class(ontology, ac, ssutil, do_log=do_log)
 		ss = tss
 	elif params['query']['query_ss_type'] == 'obj':
